@@ -1,16 +1,14 @@
-import beartype
 import copy
 
-from .compat import *
 from .utils import *
 
 
 class MetaClass(type):
-    def __new__(cls, name, bases, attr):
+    def __new__(mcs, name, bases, attr):
         # Replace each function with type checked one
         for key, value in attr.items():
             if not key.startswith("_"):
-                if type(value) is FunctionType or type(value) is MethodType:
+                if type(value) is FunctionType:
                     attr[key] = my_beartype(value)
                 elif isinstance(value, classmethod):
                     attr[key] = classmethod(my_beartype(value.__func__))
@@ -18,7 +16,7 @@ class MetaClass(type):
                     attr[key] = staticmethod(my_beartype(value.__func__))
                 # elif isinstance(value, property):
 
-        return super(MetaClass, cls).__new__(cls, name, bases, attr)
+        return super(MetaClass, mcs).__new__(mcs, name, bases, attr)
 
 
 class BaseModel(metaclass=MetaClass):
@@ -77,7 +75,40 @@ class BaseModel(metaclass=MetaClass):
         if hasattr(cls, "__annotations__"):
             return cls.__annotations__.get(key)
 
+    @classmethod
+    def _get_value(cls, v, to_dict: bool):
+        if not to_dict:
+            return v
+
+        if hasattr(v, 'dict'):
+            return v.dict()
+
+        if isinstance(v, dict):
+            return {
+                key: cls._get_value(val, to_dict=to_dict)
+                for key, val in v.items()
+            }
+        if isinstance(v, list):
+            return [
+                cls._get_value(val, to_dict=to_dict) for val in v
+            ]
+
+        return v
+
+    def dict(self) -> Dict[str, Any]:
+        result = {}
+        for key in self._keys():
+            val = getattr(self, key)
+            result[key] = type(self)._get_value(val, to_dict=True)
+        return result
+
     def __setattr__(self, key, value):
         annotation = type(self)._get_annotation(key) or Any
         check_pep_type_raise_exception(value, annotation)
         object.__setattr__(self, key, value)
+
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, d):
+        self.__dict__.update(d)
